import React, { useState } from 'react';
import styled from 'styled-components';

import { ButtonToggleState as B } from '../ButtonToggleState/ButtonToggleState';

import { Header } from '../../typography';
import { Plus, Checkmark, DismissX } from '../../icons';

const ButtonToggleState = styled(B)`
  margin: 0 1rem 1rem 0;
`;

export default {
  title: 'components/ButtonToggleState',
  component: B,
};

export function ButtonToggleStateStory({ args }) {
  const [following, setFollowing] = useState(false);
  const toggleFollowing = () =>
    setFollowing((following) => !following);

  return (
    <ButtonToggleState
      {...args}
      variant="solid"
      isActive={following}
      onClick={toggleFollowing}
      offStateText="Follow"
      onStateText="Following"
      turnOffActionText="Unfollow"
      offIcon={<Plus />}
      onIcon={<Checkmark />}
      turnOffIcon={<DismissX />}
    />
  );
}

export function AllStatesStory({ args }) {
  return (
    <>
      {/** Primary format, inactive state */}
      <Header size="6">Inactive</Header>
      <ButtonToggleState
        {...args}
        variant="solid"
        isActive={false}
        offStateText="Follow"
        onStateText="Following"
        turnOffActionText="Unfollow"
        offIcon={<Plus />}
        onIcon={<Checkmark />}
        turnOffIcon={<DismissX />}
      />
      <br />
      {/** Primary format, hover state */}
      <Header size="6">Hover</Header>
      <ButtonToggleState
        format="secondary"
        variant="solid"
        offStateText="Unfollow"
        onStateText="Unfollow"
        turnOffActionText="Unfollow"
        offIcon={<DismissX />}
        onIcon={<DismissX />}
        turnOffIcon={<DismissX />}
      />
      <br />
      {/** Primary format, active state */}
      <Header size="6">Active</Header>
      <ButtonToggleState
        variant="solid"
        isActive={true}
        offStateText="Follow"
        onStateText="Following"
        turnOffActionText="Unfollow"
        offIcon={<Plus />}
        onIcon={<Checkmark />}
        turnOffIcon={<DismissX />}
      />
    </>
  );
}

export function FormatStory({ args }) {
  const [following, setFollowing] = useState(false);
  const toggleFollowing = () =>
    setFollowing((following) => !following);

  return (
    <>
      <ButtonToggleState
        {...args}
        variant="solid"
        isActive={following}
        onClick={toggleFollowing}
        offStateText="Follow"
        onStateText="Following"
        turnOffActionText="Unfollow"
        offIcon={<Plus />}
        onIcon={<Checkmark />}
        turnOffIcon={<DismissX />}
      />
      <ButtonToggleState
        format="secondary"
        variant="solid"
        isActive={following}
        onClick={toggleFollowing}
        offStateText="Follow"
        onStateText="Following"
        turnOffActionText="Unfollow"
        offIcon={<Plus />}
        onIcon={<Checkmark />}
        turnOffIcon={<DismissX />}
      />
    </>
  );
}
